@@ -15,6 +15,12 @@ MODULE_NAME = "tcconfig"
 logger.disable(MODULE_NAME)
 
 
+class LogLevel:
+    DEBUG = "DEBUG"
+    INFO = "INFO"
+    QUIET = "QUIET"
+
+
 def set_logger(is_enable):
     if is_enable:
         logger.enable(MODULE_NAME)
@@ -26,7 +32,11 @@ def set_logger(is_enable):
 
 
 def set_log_level(log_level):
-    if log_level == "DEBUG":
+    if log_level == LogLevel.QUIET:
+        logger.disable(MODULE_NAME)
+        return
+
+    if log_level == LogLevel.DEBUG:
         log_format = (
             "<level>{level: <8}</level> | "
             "<cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>"
@@ -37,7 +47,7 @@ def set_log_level(log_level):
     logger.remove()
     logger.add(sys.stderr, colorize=True, format=log_format, level=log_level)
 
-    if log_level == "QUIET":
+    if log_level == LogLevel.QUIET:
         set_logger(is_enable=False)
     else:
         set_logger(is_enable=True)
