@@ -1,22 +1,18 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import hashlib
+from textwrap import dedent
 
-import six
+import humanreadable as hr
 import typepy
 from typepy import RealNumber
 
 from ._common import validate_within_min_max
-from ._const import KILO_SIZE, Tc
-from ._converter import HumanReadableBits, HumanReadableTime
-from ._error import ParameterError, UnitNotFoundError
-from ._network import get_no_limit_kbits
+from ._const import DELAY_DISTRIBUTIONS, Tc
+from ._logger import logger
+from ._network import get_upper_limit_rate
 
 
 MIN_PACKET_LOSS_RATE = 0  # [%]
@@ -39,14 +35,10 @@ def convert_rate_to_f(rate):
     return rate
 
 
-class NetemParameter(object):
+class NetemParameter:
     @property
     def bandwidth_rate(self):
-        # convert bandwidth string [K/M/G bit per second] to a number
-        try:
-            return HumanReadableBits(self.__bandwidth_rate, kilo_size=KILO_SIZE).to_kilobits()
-        except (ParameterError, UnitNotFoundError, TypeError):
-            return None
+        return self.__bandwidth_rate
 
     def __init__(
         self,
@@ -54,6 +46,7 @@ class NetemParameter(object):
         bandwidth_rate=None,
         latency_time=None,
         latency_distro_time=None,
+        latency_distribution=None,
         packet_loss_rate=None,
         packet_duplicate_rate=None,
         corruption_rate=None,
@@ -61,14 +54,48 @@ class NetemParameter(object):
     ):
         self.__device = device
 
-        self.__bandwidth_rate = bandwidth_rate
-        self.__latency_time = HumanReadableTime(latency_time)
-        self.__latency_distro_time = HumanReadableTime(latency_distro_time)
+        self.__bandwidth_rate = self.__normalize_bandwidth_rate(bandwidth_rate)
         self.__packet_loss_rate = convert_rate_to_f(packet_loss_rate)  # [%]
         self.__packet_duplicate_rate = convert_rate_to_f(packet_duplicate_rate)  # [%]
         self.__corruption_rate = convert_rate_to_f(corruption_rate)  # [%]
         self.__reordering_rate = convert_rate_to_f(reordering_rate)  # [%]
 
+        self.__latency_time = None
+        if latency_time:
+            self.__latency_time = hr.Time(latency_time, hr.Time.Unit.MILLISECOND)
+
+        self.__latency_distro_time = None
+        if latency_distro_time:
+            self.__latency_distro_time = hr.Time(latency_distro_time, hr.Time.Unit.MILLISECOND)
+
+        self.__latency_distribution = (
+            "normal" if latency_distribution is None else latency_distribution
+        )
+        if self.__latency_distribution not in DELAY_DISTRIBUTIONS:
+            raise ValueError("latency_distribution must be one of {}".format(DELAY_DISTRIBUTIONS))
+
+    def __normalize_bandwidth_rate(self, bandwidth_rate):
+        if not bandwidth_rate:
+            return None
+
+        hr_bps = hr.BitPerSecond(bandwidth_rate)
+        upper_limit_rate = get_upper_limit_rate(self.__device)
+
+        if hr_bps > upper_limit_rate:
+            logger.info(
+                dedent(
+                    """\
+                    clipping specified bandwidth rate limit with the {device} maximum bandwidth rate
+                    ({value}Mbps -> {limit}Mbps)
+                    """
+                ).format(
+                    value=hr_bps.mega_bps, limit=upper_limit_rate.mega_bps, device=self.__device
+                )
+            )
+            hr_bps = upper_limit_rate
+
+        return hr_bps
+
     def validate_netem_parameter(self):
         self.validate_bandwidth_rate()
         self.__validate_network_delay()
@@ -78,58 +105,60 @@ class NetemParameter(object):
         self.__validate_reordering_rate()
         self.__validate_reordering_and_delay()
 
-        netem_param_value_list = [
-            self.bandwidth_rate,
+        netem_param_values = [
             self.__packet_loss_rate,
             self.__packet_duplicate_rate,
             self.__corruption_rate,
             self.__reordering_rate,
         ]
+        if self.__bandwidth_rate:
+            netem_param_values.append(self.__bandwidth_rate.kilo_bps)
 
-        if all(
-            [
-                not RealNumber(netem_param_value).is_type() or netem_param_value <= 0
-                for netem_param_value in netem_param_value_list
-            ]
-            + [self.__latency_time <= HumanReadableTime(Tc.ValueRange.LatencyTime.MIN)]
-        ):
-            raise ParameterError(
+        check_results = [
+            not RealNumber(netem_param_value).is_type() or netem_param_value <= 0
+            for netem_param_value in netem_param_values
+        ]
+
+        if self.__latency_time:
+            check_results.append(self.__latency_time <= hr.Time(Tc.ValueRange.LatencyTime.MIN))
+
+        if all(check_results):
+            raise hr.ParameterError(
                 "there are no valid net emulation parameters found. "
                 "at least one or more following parameters are required: "
                 "--rate, --delay, --loss, --duplicate, --corrupt, --reordering"
             )
 
     def validate_bandwidth_rate(self):
-        if typepy.is_null_string(self.__bandwidth_rate):
+        hr_bps = self.__bandwidth_rate
+
+        if not hr_bps:
             return
 
-        # convert bandwidth string [K/M/G bit per second] to a number
-        hr_bits = HumanReadableBits(self.__bandwidth_rate, kilo_size=KILO_SIZE)
-
-        if hr_bits.to_bits() < 8:
-            raise ParameterError(
-                "bandwidth rate must be greater or equals to 8bps", value=hr_bits.to_bits()
+        if hr_bps.bps < 8:
+            raise hr.ParameterError(
+                "bandwidth rate must be greater or equals to 8bps", value="{}bps".format(hr_bps.bps)
             )
 
-        no_limit_kbits = get_no_limit_kbits(self.__device)
-        if hr_bits.to_kilobits() > no_limit_kbits:
-            raise ParameterError(
+        upper_limit_rate = get_upper_limit_rate(self.__device)
+        if hr_bps > upper_limit_rate:
+            raise hr.ParameterError(
                 "exceed bandwidth rate limit",
-                value="{} kbps".format(hr_bits.to_kilobits()),
-                expected="less than {} kbps".format(no_limit_kbits),
+                value="{} kbps".format(hr_bps.kilo_bps),
+                expected="less than {} kbps".format(upper_limit_rate.kilo_bps),
             )
 
     def make_param_name(self):
         item_list = [self.__device]
 
         if self.bandwidth_rate:
-            item_list.append("rate{}".format(self.bandwidth_rate))
+            item_list.append("rate{}kbps".format(int(self.bandwidth_rate.kilo_bps)))
 
-        if self.__latency_time.get_msec():
-            item_list.append("delay{}".format(self.__latency_time))
+        if self.__latency_time and self.__latency_time.milliseconds > 0:
+            item_list.append("delay{}".format(self.__latency_time.milliseconds))
 
-        if self.__latency_distro_time.get_msec():
-            item_list.append("distro{}".format(self.__latency_distro_time))
+        if self.__latency_distro_time and self.__latency_distro_time.milliseconds > 0:
+            item_list.append("distro{}".format(self.__latency_distro_time.milliseconds))
 
         if self.__packet_loss_rate:
             item_list.append("loss{}".format(self.__packet_loss_rate))
@@ -154,11 +183,17 @@ class NetemParameter(object):
         if self.__packet_duplicate_rate > 0:
             item_list.append("duplicate {:f}%".format(self.__packet_duplicate_rate))
 
-        if self.__latency_time > HumanReadableTime(Tc.ValueRange.LatencyTime.MIN):
-            item_list.append("delay {}".format(self.__latency_time))
+        if self.__latency_time and self.__latency_time > hr.Time(Tc.ValueRange.LatencyTime.MIN):
+            item_list.append("delay {}ms".format(self.__latency_time.milliseconds))
 
-            if self.__latency_distro_time > HumanReadableTime(Tc.ValueRange.LatencyTime.MIN):
-                item_list.append("{} distribution normal".format(self.__latency_distro_time))
+            if self.__latency_distro_time and self.__latency_distro_time > hr.Time(
+                Tc.ValueRange.LatencyTime.MIN
+            ):
+                item_list.append(
+                    "{}ms distribution {}".format(
+                        self.__latency_distro_time.milliseconds, self.__latency_distribution
+                    )
+                )
 
         if self.__corruption_rate > 0:
             item_list.append("corrupt {:f}%".format(self.__corruption_rate))
@@ -169,7 +204,7 @@ class NetemParameter(object):
         return " ".join(item_list)
 
     def calc_hash(self, extra=""):
-        return hashlib.md5(six.b(self.make_param_name() + extra)).hexdigest()
+        return hashlib.md5((self.make_param_name() + extra).encode("latin-1")).hexdigest()
 
     def calc_device_qdisc_major_id(self):
         base_device_hash = self.calc_hash()[:3]
@@ -178,19 +213,21 @@ class NetemParameter(object):
         return int(device_hash_prefix + base_device_hash, 16)
 
     def __validate_network_delay(self):
-        try:
-            self.__latency_time.validate(
-                min_value=Tc.ValueRange.LatencyTime.MIN, max_value=Tc.ValueRange.LatencyTime.MAX
-            )
-        except ParameterError as e:
-            raise ParameterError("delay {}".format(e))
+        if self.__latency_time:
+            try:
+                self.__latency_time.validate(
+                    min_value=Tc.ValueRange.LatencyTime.MIN, max_value=Tc.ValueRange.LatencyTime.MAX
+                )
+            except hr.ParameterError as e:
+                raise hr.ParameterError("delay {}".format(e))
 
-        try:
-            self.__latency_distro_time.validate(
-                min_value=Tc.ValueRange.LatencyTime.MIN, max_value=Tc.ValueRange.LatencyTime.MAX
-            )
-        except ParameterError as e:
-            raise ParameterError("delay-distro {}".format(e))
+        if self.__latency_distro_time:
+            try:
+                self.__latency_distro_time.validate(
+                    min_value=Tc.ValueRange.LatencyTime.MIN, max_value=Tc.ValueRange.LatencyTime.MAX
+                )
+            except hr.ParameterError as e:
+                raise hr.ParameterError("delay-distro {}".format(e))
 
     def __validate_packet_loss_rate(self):
         validate_within_min_max(
@@ -229,5 +266,5 @@ class NetemParameter(object):
         )
 
     def __validate_reordering_and_delay(self):
-        if self.__reordering_rate and self.__latency_time.get_msec() <= 0:
-            raise ParameterError("reordering needs latency to be specified: set latency > 0")
+        if self.__reordering_rate and self.__latency_time and self.__latency_time.milliseconds <= 0:
+            raise hr.ParameterError("reordering needs latency to be specified: set latency > 0")
