@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
@@ -8,9 +6,9 @@ import itertools
 
 import pytest
 from allpairspy import AllPairs
+from humanreadable import ParameterError
 
 from tcconfig._const import ShapingAlgorithm, Tc, TrafficDirection
-from tcconfig._error import ParameterError, UnitNotFoundError
 from tcconfig._netem_param import (
     MAX_CORRUPTION_RATE,
     MAX_PACKET_DUPLICATE_RATE,
@@ -41,27 +39,8 @@ def device_option(request):
         ["".join(opt_list)]
         for opt_list in AllPairs(
             [
-                ["0.1", "+1.25", "30"],
-                [
-                    "k",
-                    " k ",
-                    "K",
-                    " K ",
-                    "kbps",
-                    "Kbps",
-                    "m",
-                    " m ",
-                    "M",
-                    " M ",
-                    "mbps",
-                    "Mbps",
-                    "g",
-                    " g ",
-                    "G",
-                    " G ",
-                    "gbps",
-                    "Gbps",
-                ],
+                ["0.1", "+1.25", "25"],
+                ["kbps", "Kbps", " Kibps", "mbps", "Mbps", " Mibps", "gbps", "Gbps", " Gibps"],
             ]
         )
     ],
@@ -79,11 +58,11 @@ def test_TrafficControl_validate_bandwidth_rate_normal(value):
 @pytest.mark.parametrize(
     ["value", "expected"],
     [
-        ["".join(opt_list), UnitNotFoundError]
+        ["".join(opt_list), ParameterError]
         for opt_list in AllPairs([["0.1", "1"], ["", "kb", "KB", "mb", "MB", "gb", "GB"]])
     ]
     + [["".join(value), ParameterError] for value in ("B", "K", "M", "G")]
-    + [["0bps", ParameterError], ["34359738361bps", ParameterError]],
+    + [["0bps", ParameterError]],
 )
 def test_TrafficControl_validate_bandwidth_rate_exception_1(value, expected):
     with pytest.raises(expected):
@@ -105,7 +84,7 @@ def test_TrafficControl_validate_bandwidth_rate_exception_1(value, expected):
     ["value", "expected"],
     [
         ["".join(opt_list), ParameterError]
-        for opt_list in itertools.product(["-1", "0", "0.0"], ["k", "K", "m", "M", "g", "G"])
+        for opt_list in itertools.product(["-1", "0", "0.0"], ["bps", "Kbps", "MKbps", "GKbps"])
     ],
 )
 def test_TrafficControl_validate_bandwidth_rate_exception_2(value, expected):
@@ -123,7 +102,7 @@ def test_TrafficControl_validate_bandwidth_rate_exception_2(value, expected):
         tc_obj.netem_param.validate_bandwidth_rate()
 
 
-class Test_TrafficControl_validate(object):
+class Test_TrafficControl_validate:
     @pytest.mark.parametrize(
         [
             "rate",
@@ -147,7 +126,7 @@ class Test_TrafficControl_validate(object):
             opt_list
             for opt_list in AllPairs(
                 [
-                    [None, "", "100K", "0.5M", "0.1G"],  # rate
+                    [None, "", "100Kbps", "0.5Mbps", "0.1Gbps"],  # rate
                     [TrafficDirection.OUTGOING],
                     [Tc.ValueRange.LatencyTime.MIN, Tc.ValueRange.LatencyTime.MAX],  # delay
                     [Tc.ValueRange.LatencyTime.MIN, Tc.ValueRange.LatencyTime.MAX],  # delay_distro
@@ -323,7 +302,7 @@ class Test_TrafficControl_validate(object):
             tc_obj.validate()
 
 
-class Test_TrafficControl_ipv4(object):
+class Test_TrafficControl_ipv4:
     @pytest.mark.parametrize(
         ["network", "is_ipv6", "expected_ip_ver", "expected_protocol", "expected_protocol_match"],
         [
